searchData={"items":[{"type":"task","title":"mix rdmx.update","doc":"Updates Readmix blocks in a file.\n\nA backup of updated files is automatically done in the system temporary\ndirectory.\n\nReadmix will use the default generators and context defined in the\nconfiguration for the `:readmix` application, under the `:generators` and\n`:contexts` keys:\n\n```elixir\n# dev.exs\n\nconfig :readmix,\n  generators: [MyGenerator],\n  contexts: [MyContext, Readmix.Contexts.Defaults]\n```","ref":"Mix.Tasks.Rdmx.Update.html"},{"type":"task","title":"Usage - mix rdmx.update","doc":"```shell\nmix rdmx.update [options]  \n```","ref":"Mix.Tasks.Rdmx.Update.html#module-usage"},{"type":"task","title":"Options - mix rdmx.update","doc":"* `-b, --backup`- Perform a backup of the updated files. Defaults to `true`.\n* `-d, --backup-dir  `- Target directory to backup files before update. Defaults to `System.tmp_dir!()`.\n* `--var  `- Provide variables for generators using the\n  `Readmix.Contexts.Defaults` context.\n  \n  Variables must be given with a key and value:\n  \n      --var \"some_key=some_value\"\n  \n* `--help`- Displays this help.","ref":"Mix.Tasks.Rdmx.Update.html#module-options"},{"type":"task","title":"Examples - mix rdmx.update","doc":"```bash\n# Update a single file\nmix rdmx.update README.md\n\n# Update with custom variables\nmix rdmx.update README.md --var \"app_vsn=1.2.3\"\n\n# Update without backup\nmix rdmx.update README.md --no-backup\n```","ref":"Mix.Tasks.Rdmx.Update.html#module-examples"},{"type":"module","title":"Readmix","doc":"Readmix is a tool for generating and maintaining documentation with dynamic\ncontent.\n\nIt allows you to embed special tags in your markdown or other text files that\nwill be processed and replaced with generated content.","ref":"Readmix.html"},{"type":"module","title":"Basic Usage - Readmix","doc":"```elixir\n# Create a new Readmix instance\nrdmx = Readmix.new([])\n\n# Update a file containing Readmix blocks\nReadmix.update_file(rdmx, \"README.md\")\n```","ref":"Readmix.html#module-basic-usage"},{"type":"module","title":"Block Format - Readmix","doc":"Readmix blocks are defined in HTML comments with a special `rdmx` prefix:\n\n```\n<!-- rdmx my_namespace:my_action param1:\"value1\" param2:$my_var -->\nThis content will be replaced by the generator.\n<!-- rdmx my_namespace:my_action -->\n```","ref":"Readmix.html#module-block-format"},{"type":"module","title":"Configuration - Readmix","doc":"You can configure Readmix with custom generators, variables, and context\nmodules:\n\n```elixir\nReadmix.new(\n  generators: %{my_namespace: MyGeneratorModule},\n  vars: %{my_var: \"hello\"},\n  contexts: [MyContext, Readmix.Contexts.Defaults]\n)\n```","ref":"Readmix.html#module-configuration"},{"type":"function","title":"Readmix.blocks_to_iodata/2","doc":"","ref":"Readmix.html#blocks_to_iodata/2"},{"type":"function","title":"Readmix.default_contexts/0","doc":"Returns the list of modules used to define the context of execution. For now\nthis only defines which variables are available for usage in blocks arguments.\n\nThose defaults are pulled with `Application.fetch_env(:readmix, :contexts)`,\nwhich is a configuration value that you can define in `config/dev.exs` or\n`config/runtime.exs`.\n\nIf not configuration is defined, the default value is\n`[Readmix.Contexts.Defaults]`.","ref":"Readmix.html#default_contexts/0"},{"type":"function","title":"Readmix.default_generators/0","doc":"Returns the mapping from namespace to generator used by default by Readmix if\nno `:resolver` or `:generators` option is given to `Readmix.new/1`.\n\nThose defaults are pulled with `Application.fetch_env(:readmix, :generators)`,\nwhich is a configuration value that you can define in `config/dev.exs` or\n`config/runtime.exs`.\n\nIf not configuration is defined, the default value is\n`%{rdmx: Readmix.Generators.BuiltIn}`.","ref":"Readmix.html#default_generators/0"},{"type":"function","title":"Readmix.format_error/1","doc":"","ref":"Readmix.html#format_error/1"},{"type":"function","title":"Readmix.new/1","doc":"","ref":"Readmix.html#new/1"},{"type":"function","title":"Readmix.parse_string/2","doc":"","ref":"Readmix.html#parse_string/2"},{"type":"type","title":"Readmix.t/0","doc":"","ref":"Readmix.html#t:t/0"},{"type":"function","title":"Readmix.transform_string/3","doc":"","ref":"Readmix.html#transform_string/3"},{"type":"function","title":"Readmix.transform_string_to_iodata/3","doc":"","ref":"Readmix.html#transform_string_to_iodata/3"},{"type":"function","title":"Readmix.update_file/2","doc":"","ref":"Readmix.html#update_file/2"},{"type":"module","title":"Readmix.BlockSpec","doc":"Defines the structure for generated blocks found in documents.","ref":"Readmix.BlockSpec.html"},{"type":"type","title":"Readmix.BlockSpec.t/0","doc":"","ref":"Readmix.BlockSpec.html#t:t/0"},{"type":"behaviour","title":"Readmix.Context","doc":"Defines the context behaviour for Readmix contexts.\n\nA context is used to define variables used in Readmix blocks, such as:\n\n```markdown\n<!-- rdmx :app_dep vsn:$my_custom_variable -->\nsome content\n<!-- rdmx /:app_dep -->\n```\n\nTo define `$my_custom_variable`, a context module could be defined like so:\n\n```elixir\ndefmodule MyContext do\n  @behaviour Readmix.Context\n\n  @impl true\n  def get_vars do\n    %{my_custom_variable: \"1.2.3\"}\n  end\nend\n```\n\nContext can be provided with the `:contexts` options for `Readmix.new/1`.","ref":"Readmix.Context.html"},{"type":"callback","title":"Readmix.Context.get_vars/0","doc":"","ref":"Readmix.Context.html#c:get_vars/0"},{"type":"type","title":"Readmix.Context.vars/0","doc":"","ref":"Readmix.Context.html#t:vars/0"},{"type":"module","title":"Readmix.Contexts.Defaults","doc":"This is the default Readmix context for variables.\n\nEvery variable is defined as a function in this module. Refer to the functions\ndocumentation to see which variables are defined.","ref":"Readmix.Contexts.Defaults.html"},{"type":"function","title":"Readmix.Contexts.Defaults.app_vsn/0","doc":"The current application version from `mix.exs`.","ref":"Readmix.Contexts.Defaults.html#app_vsn/0"},{"type":"function","title":"Readmix.Contexts.Defaults.otp_app/0","doc":"The OTP application atom (example: `:readmix`) of the current application.","ref":"Readmix.Contexts.Defaults.html#otp_app/0"},{"type":"module","title":"Readmix.Docs","doc":"Utilities for generating documentation for Readmix generators.","ref":"Readmix.Docs.html"},{"type":"macro","title":"Readmix.Docs.generate/0","doc":"Generates documentation for the actions registered with\n`Readmix.Generator.action/2`.","ref":"Readmix.Docs.html#generate/0"},{"type":"function","title":"Readmix.Docs.generate/1","doc":"Generates documentation for actions defined as a keyword list.","ref":"Readmix.Docs.html#generate/1"},{"type":"behaviour","title":"Readmix.Generator","doc":"Defines the behavior and utilities for Readmix generators.\n\nGenerators are modules that implement this behaviour and provide actions that\ncan be invoked from documents.\n\nTo create a generator, use:\n\n```elixir\ndefmodule MyGenerator do\n  use Readmix.Generator\n\n  @doc \"This action does something\"\n  action :my_action,\n    as: :generate_my,\n    params: [\n      param1: [type: :string, doc: \"Parameter documentation\"]\n    ]\n\n  @moduledoc \"\"\"\n  My custom actions.\n\n  #{Readmix.Docs.generate()}\n  \"\"\"\n\n  defp generate_my(params, context) do\n    {:ok, \"Generated content\"}\n  end\nend\n```\n\nThis is equivalent to the following:\n\n```elixir\ndefmodule MyGenerator do\n  @behaviour Readmix.Generator\n\n  @actions [\n    my_action: [\n      as: :generate_my,\n      params: [\n        param1: [type: :string, doc: \"Parameter documentation\"]\n      ],\n      doc: \"This action does something\"\n    ]\n  ]\n\n  @moduledoc \"\"\"\n  My custom actions.\n\n  #{Readmix.Docs.generate(@actions)}\n  \"\"\"\n\n  @impl true\n  def actions, do: action\n\n  @impl true\n  def generate(:my_action, params, context) do\n    generate_my(params, context)\n  end\n\n  defp generate_my(params, context) do\n    {:ok, \"Generated content\"}\n  end\nend\n```","ref":"Readmix.Generator.html"},{"type":"macro","title":"Readmix.Generator.action/2","doc":"","ref":"Readmix.Generator.html#action/2"},{"type":"type","title":"Readmix.Generator.action_name/0","doc":"","ref":"Readmix.Generator.html#t:action_name/0"},{"type":"type","title":"Readmix.Generator.action_spec/0","doc":"","ref":"Readmix.Generator.html#t:action_spec/0"},{"type":"type","title":"Readmix.Generator.action_spec_opt/0","doc":"","ref":"Readmix.Generator.html#t:action_spec_opt/0"},{"type":"callback","title":"Readmix.Generator.actions/0","doc":"","ref":"Readmix.Generator.html#c:actions/0"},{"type":"type","title":"Readmix.Generator.block/0","doc":"","ref":"Readmix.Generator.html#t:block/0"},{"type":"type","title":"Readmix.Generator.block_name/0","doc":"","ref":"Readmix.Generator.html#t:block_name/0"},{"type":"type","title":"Readmix.Generator.block_spec/0","doc":"","ref":"Readmix.Generator.html#t:block_spec/0"},{"type":"type","title":"Readmix.Generator.context/0","doc":"","ref":"Readmix.Generator.html#t:context/0"},{"type":"macro","title":"Readmix.Generator.dispatch_actions/1","doc":"","ref":"Readmix.Generator.html#dispatch_actions/1"},{"type":"callback","title":"Readmix.Generator.generate/3","doc":"","ref":"Readmix.Generator.html#c:generate/3"},{"type":"function","title":"Readmix.Generator.get_arg/3","doc":"","ref":"Readmix.Generator.html#get_arg/3"},{"type":"function","title":"Readmix.Generator.or_var/2","doc":"Returns a function that reads the given key from the given context.\n\n\nThe returned function with throw `{:undef_var, key}` if the variable is not\ndefined.\n\nThis is intended to be used as a default getter for `get_arg`, so there is an\nattempt to read a variable only when the argument is not defined.","ref":"Readmix.Generator.html#or_var/2"},{"type":"type","title":"Readmix.Generator.params/0","doc":"","ref":"Readmix.Generator.html#t:params/0"},{"type":"module","title":"Readmix.Generators.BuiltIn","doc":"Implements the built-in generators for Readmix.","ref":"Readmix.Generators.BuiltIn.html"},{"type":"module","title":"Actions - Readmix.Generators.BuiltIn","doc":"#### app_dep\nGenerates a fenced code block for the `deps` function in `mix.exs`, pulling a\npackage from hex.pm.\n\n\n##### Parameters \n* `:otp_app` (`t:String.t/0`) - The OTP application to use in the dependency tuple. Defaults to the current application.\n\n* `:vsn` (`t:String.t/0`) - The version number to use. Defaults to the current version of the OTP application.\n\n* `:comma` (`t:boolean/0`) - Include a comma after the dependency tuple. The default value is `true`.\n\n* `:patch` (`t:boolean/0`) - Include the patch in the version number in the dependency tuple. The default value is `false`.\n\n* `:only` (`t:String.t/0`) - Adds the `:only` option to the dependency tuple. Multiple environments can be separated with commas.\n\n* `:runtime` (`t:boolean/0`) - When `false`, adds the `runtime: false` option to the dependency tuple.\n\n#### badges\nGenerates badges with `img.shields.io`.\n\nBadges are generated in the order of the action params.\n\n\n##### Parameters \n* `:hexpm` (`t:String.t/0`) - Generates a badge linking to [hex.pm](https://hex.pm/).\n\n  Requires a package name and an optional query string for customization.\n\n  Example: `\"readmix?color=4e2a8e\"`.\n\n* `:github_action` (`t:String.t/0`) - Generates a badge linking to the latest Github Action.\n\n  Requires a package name and an optional query string for customization\n  and limiting to a branch name.\n\n  Example: `\"lud/readmix/elixir.yaml?label=CI&branch=main\"`.\n\n* `:license` (`t:String.t/0`) - Generates a badge linking to a license for an _Elixir_ package.\n\n  Requires an hex.pm package name.\n\n  Example: `\"readmix\"`.","ref":"Readmix.Generators.BuiltIn.html#module-actions"},{"type":"module","title":"Readmix.Parser","doc":"Parses documents for Readmix blocks embedded in HTML comments.\n\nThis module handles parsing source documents containing tags in the following\nformat:\n\n```\n<!-- rdmx some_namespace:some_action param1:123 param2:\"hello\" -->\ncontent\n<!-- rdmx /some_namespace:some_action -->\n```","ref":"Readmix.Parser.html"},{"type":"function","title":"Readmix.Parser.parse_string/2","doc":"","ref":"Readmix.Parser.html#parse_string/2"},{"type":"exception","title":"Readmix.Error","doc":"A generic exception for Readmix errors.","ref":"Readmix.Error.html"},{"type":"function","title":"Readmix.Error.message/1","doc":"","ref":"Readmix.Error.html#message/1"},{"type":"exception","title":"Readmix.Parser.ParseError","doc":"","ref":"Readmix.Parser.ParseError.html"},{"type":"function","title":"Readmix.Parser.ParseError.message/1","doc":"","ref":"Readmix.Parser.ParseError.html#message/1"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}